@@ -14,9 +14,17 @@ def run():
     parser.add_argument('account', type=str, help="Facebook account or group")
     parser.add_argument('-f', '--filename', type=str, help="Output filename")
     parser.add_argument('-p', '--pages', type=int, help="Number of pages to download", default=10)
+    parser.add_argument(
+        '-t',
+        '--timeout',
+        type=int,
+        help="How long to wait in seconds for Facebook servers before aborting",
+        default=10,
+    )
     parser.add_argument('-g', '--group', action='store_true', help="Use group scraper")
     parser.add_argument('-v', '--verbose', action='count', help="Enable logging", default=0)
     parser.add_argument('-c', '--cookies', type=str, help="Path to a cookies file")
+    parser.add_argument('--comments', action='store_true', help="Extract comments")
     parser.add_argument('-r', '--reactions', action='store_true', help="Extract reactions")
     parser.add_argument('-rs', '--reactors', action='store_true', help="Extract reactors")
     parser.add_argument(
@@ -37,7 +45,16 @@ def run():
 
     # Choose the right argument to pass to write_posts_to_csv (group or account)
     account_type = 'group' if args.group else 'account'
-    kwargs = {account_type: args.account, "cookies": args.cookies, "options": {"reactions": args.reactions, "reactors": args.reactors}}
+    kwargs = {
+        account_type: args.account,
+        "cookies": args.cookies,
+        "timeout": args.timeout,
+        "options": {
+            "reactions": args.reactions,
+            "reactors": args.reactors,
+            "comments": args.comments,
+        },
+    }
 
     # Enable logging
     if args.verbose > 0:
