@@ -401,8 +401,14 @@ class PostExtractor:
             )
             or self.live_data.get("like_count")
             or self.live_data.get("reactioncount")
-            or (self.element.find(".likes", first=True) and utils.parse_int(self.element.find(".likes", first=True).text))
-            or (self.element.find(".like_def", first=True) and utils.parse_int(self.element.find(".like_def", first=True).text))
+            or (
+                self.element.find(".likes", first=True)
+                and utils.parse_int(self.element.find(".likes", first=True).text)
+            )
+            or (
+                self.element.find(".like_def", first=True)
+                and utils.parse_int(self.element.find(".like_def", first=True).text)
+            )
             or 0,
         }
 
@@ -412,7 +418,10 @@ class PostExtractor:
                 self.element, 'footer', self.comments_regex, utils.convert_numeric_abbr
             )
             or self.live_data.get("comment_count")
-            or (self.element.find(".cmt_def", first=True) and utils.parse_int(self.element.find(".cmt_def", first=True).text))
+            or (
+                self.element.find(".cmt_def", first=True)
+                and utils.parse_int(self.element.find(".cmt_def", first=True).text)
+            )
             or 0,
         }
 
@@ -670,18 +679,19 @@ class PostExtractor:
         if photoset_link and photoset_link.find("i[aria-label='video']"):
             query = parse_qs(urlparse(photoset_link.attrs.get("href")).query)
             video_id = query["photo"][0]
-            logger.debug(f"Fetching {video_id}")
-            response = self.request(video_id)
-            video_post = PostExtractor(
-                response.html, self.options, self.request, full_post_html=response.html
-            )
-            video_post.post = {"post_id": video_id}
-            meta = video_post.extract_video_meta() or {}
-            return {
-                "video_id": video_id,
-                "video": video_post.extract_video().get("video"),
-                **meta,
-            }
+            if video_id != self.post["post_id"]:
+                logger.debug(f"Fetching {video_id}")
+                response = self.request(video_id)
+                video_post = PostExtractor(
+                    response.html, self.options, self.request, full_post_html=response.html
+                )
+                video_post.post = {"post_id": video_id}
+                meta = video_post.extract_video_meta() or {}
+                return {
+                    "video_id": video_id,
+                    "video": video_post.extract_video().get("video"),
+                    **meta,
+                }
 
         if video_data_element is None:
             return None
@@ -832,7 +842,9 @@ class PostExtractor:
             "div:not([data-sigil])>a[href]:not([data-click]):not([data-store]):not([data-sigil])",
             first=True,
         )
-        comment_body_elem = comment.find('[data-sigil="comment-body"],div._14ye,div.bl', first=True)
+        comment_body_elem = comment.find(
+            '[data-sigil="comment-body"],div._14ye,div.bl', first=True
+        )
         if comment_body_elem:
             text = comment_body_elem.text
         else:
@@ -876,20 +888,21 @@ class PostExtractor:
     def extract_comments_full(self):
         """Fetch comments for an existing post obtained by `get_posts`.
         Note that this method may raise multiple http requests per post to get all comments"""
-        comments_area_selector = 'div.ufi>div:last-child'
+        comments_area_selector = 'div.ufi'
         elem = self.full_post_html.find(comments_area_selector, first=True)
-        comments_selector = 'div[data-sigil="comment"],div._55wr'
+        comments_selector = 'div[data-sigil="comment"]'
+        if self.options.get("noscript"):
+            comments_selector = "div._55wr"
         comments = list(elem.find(comments_selector))
         if not comments:
             logger.warning("No comments found on page")
             return
 
-        more_selector = f"a[href*='{self.post.get('post_id')}']"
-        direction = "View more comments"
-        more = elem.find(more_selector, containing=direction, first=True)
+        more_selector = f"div#see_next_{self.post.get('post_id')} a"
+        more = elem.find(more_selector, first=True)
         if not more:
-            direction = "View previous comments"
-            more = elem.find(more_selector, containing=direction, first=True)
+            more_selector = f"div#see_prev_{self.post.get('post_id')} a"
+            more = elem.find(more_selector, first=True)
 
         # Comment limiting and progress
         limit = 5000  # Default
@@ -928,7 +941,7 @@ class PostExtractor:
                 logger.warning("No comments found on page")
                 break
             comments.extend(more_comments)
-            more = elem.find(more_selector, containing=direction, first=True)
+            more = elem.find(more_selector, first=True)
 
         logger.debug(f"Found {len(comments)} comments")
         results = []
@@ -942,7 +955,8 @@ class PostExtractor:
                 logger.error(f"Unable to parse comment {comment}: {e}")
                 continue
             replies = comment.find(
-                "div.async_elem[data-sigil='replies-see-more'] a[href],div[id*='comment_replies_more'] a[href]", first=True
+                "div.async_elem[data-sigil='replies-see-more'] a[href],div[id*='comment_replies_more'] a[href]",
+                first=True,
             )
             if self.options.get("progress"):
                 pbar.update(1)
@@ -956,13 +970,16 @@ class PostExtractor:
                     logger.error(e)
                     continue
                 # Skip first element, as it will be this comment itself
-                replies = response.html.find('div[data-sigil="comment"],#root div[id]')[1:]
+                reply_selector = 'div[data-sigil="comment"]'
+                if self.options.get("noscript"):
+                    reply_selector = '#root div[id]'
+                replies = response.html.find(reply_selector)[1:]
                 try:
-                    result["replies"] = [
-                        self.parse_comment(reply) for reply in replies
-                    ]
+                    result["replies"] = [self.parse_comment(reply) for reply in replies]
                 except Exception as e:
-                    logger.error(f"Unable to parse comment {result['comment_id']} replies {replies}: {e}")
+                    logger.error(
+                        f"Unable to parse comment {result['comment_id']} replies {replies}: {e}"
+                    )
                     continue
             results.append(result)
         return {"comments_full": results}
@@ -1051,7 +1068,11 @@ class PhotoPostExtractor(PostExtractor):
 
     def extract_photo_link(self) -> PartialPost:
         image = self.extract_photo_link_HQ(self.full_post_html.html)
-        return {"image": image, "images": [image], "images_description": self.extract_image_lq()["images_lowquality_description"]}
+        return {
+            "image": image,
+            "images": [image],
+            "images_description": self.extract_image_lq()["images_lowquality_description"],
+        }
 
     def extract_user_id(self) -> PartialPost:
         match = re.search(r'entity_id:(\d+),', self.element.html)
@@ -1059,11 +1080,7 @@ class PhotoPostExtractor(PostExtractor):
             return {"user_id": match.group(1)}
 
     def extract_post_url(self) -> PartialPost:
-        return {
-            "post_url": utils.urljoin(
-                FB_MOBILE_BASE_URL, self.extract_post_id()["post_id"]
-            )
-        }
+        return {"post_url": utils.urljoin(FB_MOBILE_BASE_URL, self.extract_post_id()["post_id"])}
 
     def extract_post_id(self) -> PartialPost:
         try:
