@@ -88,9 +88,7 @@ class FacebookScraper:
             if not elem:
                 logger.warning("No raw posts (<article> elements) were found in this page.")
             else:
-                comments_area = response.html.find(
-                    'div.ufi', first=True
-                )
+                comments_area = response.html.find('div.ufi', first=True)
                 if comments_area:
                     # Makes likes/shares regexes work
                     elem = utils.make_html_element(
@@ -152,11 +150,14 @@ class FacebookScraper:
         else:
             cover_photo = response.html.find(
                 "div[data-sigil='cover-photo']>i.img", first=True
-            ).attrs["style"]
-            match = re.search(r"url\('(.+)'\)", cover_photo)
-            if match:
-                result["cover_photo"] = utils.decode_css_url(match.groups()[0])
-            result["profile_picture"] = response.html.find("img.profpic", first=True).attrs["src"]
+            )
+            if cover_photo:
+                match = re.search(r"url\('(.+)'\)", cover_photo.attrs["style"])
+                if match:
+                    result["cover_photo"] = utils.decode_css_url(match.groups()[0])
+            profpic = response.html.find("img.profpic", first=True)
+            if profpic:
+                result["profile_picture"] = profpic.attrs["src"]
 
         about_url = utils.urljoin(FB_MOBILE_BASE_URL, f'/{account}/about/')
         logger.debug(f"Requesting page from: {about_url}")
@@ -390,6 +391,7 @@ class FacebookScraper:
             not_found_titles = ["page not found", "content not found"]
             temp_ban_titles = [
                 "you can't use this feature at the moment",
+                "you can't use this feature right now",
                 "you’re temporarily blocked",
             ]
             if title:
@@ -485,6 +487,8 @@ class FacebookScraper:
         elif isinstance(options, set):
             warnings.warn("The options argument should be a dictionary.", stacklevel=3)
             options = {k: True for k in options}
+        if self.session.cookies.get("noscript") == "1":
+            options["noscript"] = True
 
         if page_limit and page_limit <= 2:
             warnings.warn(
